@@ -5,7 +5,10 @@ use serde_json::Value;
 
 use crate::{
     registry::{MetaSchema, MetaSchemaRef, Registry},
-    types::{ParseError, ParseFromJSON, ParseFromMultipartField, ParseResult, ToJSON, Type},
+    types::{
+        ParseError, ParseFromJSON, ParseFromMultipartField, ParseFromParameter, ParseResult,
+        ToJSON, Type,
+    },
 };
 
 impl<T: Type> Type for Vec<T> {
@@ -56,6 +59,25 @@ impl<T: ParseFromJSON> ParseFromJSON for Vec<T> {
     }
 }
 
+impl<T: ParseFromParameter> ParseFromParameter for Vec<T> {
+    fn parse_from_parameter(_value: &str) -> ParseResult<Self> {
+        unreachable!()
+    }
+
+    fn parse_from_parameters<I: IntoIterator<Item = A>, A: AsRef<str>>(
+        iter: I,
+    ) -> ParseResult<Self> {
+        let mut values = Vec::new();
+        for s in iter {
+            values.push(
+                T::parse_from_parameters(std::iter::once(s.as_ref()))
+                    .map_err(ParseError::propagate)?,
+            );
+        }
+        Ok(values)
+    }
+}
+
 #[poem::async_trait]
 impl<T: ParseFromMultipartField> ParseFromMultipartField for Vec<T> {
     async fn parse_from_multipart(field: Option<PoemField>) -> ParseResult<Self> {
@@ -88,3 +110,14 @@ impl<T: ToJSON> ToJSON for Vec<T> {
         Value::Array(values)
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+
+    #[test]
+    fn parse_from_parameters() {
+        let values = Vec::<i32>::parse_from_parameters(vec!["100", "200", "300"]).unwrap();
+        assert_eq!(values, vec![100, 200, 300]);
+    }
+}
